==> viqcore_flutter-1.2.2.tar.gz: lib/src/security/passport.dart <==
import 'package:flutter/foundation.dart';
import 'package:viqcore_flutter/src/http_client/adapters/http_adapter.dart';

import '../app.dart';

abstract class Passport extends ChangeNotifier {
  Identity? _identity;
  Identity? get identity => _identity;
  bool get isAuthenticated => _identity != null;

  void refresh(Identity identity) {
    assert(isAuthenticated);
    _identity = identity;
    notifyListeners();
  }

  void signedIn(Identity identity) {
    _identity = identity;
    notifyListeners();
  }

  void signOut() async {
    if (_identity == null) return;
    try {
      signOutFromServer();
    } on Exception catch (_) {}
    signedOut();
  }

  void signedOut() {
    setRefreshToken(null);
    if (_identity != null) {
      _identity = null;
      notifyListeners();
    }
  }

  void addAuthenticatedListener(VoidCallback listener) {
    addListener(() {
      if (isAuthenticated) {
        listener.call();
      }
    });
  }

  String? get refreshToken => App.box.get('passport/x-refresh-token');
  void setRefreshToken(String? token) {
    if (token == null) {
      App.box.delete('passport/x-refresh-token');
      App<API>().dio.clearCookies();
    } else {
      App.box.put('passport/x-refresh-token', token);
    }
  }

  /// A shortcut to obtain the identity in strong type.
  /// Example: `App.credential<User>()`
  T call<T extends Identity>() => identity as T;

  void onFailedAuthorizationFromServer() => signOut();
  Future signOutFromServer();
  Future refreshTokenFromServer();
}

abstract class Identity {}

@immutable
class PrincipalIdentity implements Identity {
  final String id;
  final String username;
  final String name;
  final String? email;
  final String? phone;

  const PrincipalIdentity({
    required this.id,
    required this.username,
    required this.name,
    this.email,
    this.phone,
  });

  factory PrincipalIdentity.fromJson(Map<String, Object?> json) =>
      PrincipalIdentity(
          id: json['id'] as String,
          username: json['username'] as String,
          name: json['name'] as String,
          email: json['email'] as String?);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other.runtimeType == runtimeType &&
            other is PrincipalIdentity &&
            (identical(other.id, id) || other.id == id) &&
            (identical(other.username, username) ||
                other.username == username) &&
            (identical(other.name, name) || other.name == name) &&
            (identical(other.email, email) || other.email == email) &&
            (identical(other.phone, phone) || other.phone == phone));
  }

  @override
  int get hashCode =>
      Object.hash(runtimeType, id, username, name, email, phone);
}

class DefaultPassport extends Passport {
  @override
  Future signOutFromServer() {
    return '/api/auth/signout'.api().post(
      extra: {
        'SIGN_OUT': true,
      },
    );
  }

  @override
  Future refreshTokenFromServer() async {
    return '/api/auth/refresh'.api(
      body: {
        'refreshToken': App.passport.refreshToken,
        'checkSum': Crypto.checkSum(App.passport.refreshToken!)
      },
    ).post(
      extra: {
        'RENEW_CREDENTIAL': true,
      },
    );
  }
}

==> viqcore_flutter-1.3.1.tar.gz: lib/src/security/passport.dart <==
import 'package:flutter/foundation.dart';
import 'package:viqcore_flutter/src/http_client/adapters/http_adapter.dart';

import '../app.dart';

abstract class Passport extends ChangeNotifier {
  Identity? _identity;
  Identity? get identity => _identity;
  bool get isAuthenticated => _identity != null;

  void refresh(Identity identity) {
    assert(isAuthenticated);
    _identity = identity;
    notifyListeners();
  }

  void signedIn(Identity identity) {
    _identity = identity;
    notifyListeners();
  }

  void signOut() async {
    if (_identity == null) return;
    try {
      signOutFromServer();
    } on Exception catch (_) {}
    signedOut();
  }

  void signedOut() {
    App.box.delete('passport/x-access-token');
    App.box.delete('passport/x-refresh-token');
    App<API>().dio.clearCookies();
    if (_identity != null) {
      _identity = null;
      notifyListeners();
    }
  }

  void addAuthenticatedListener(VoidCallback listener) {
    addListener(() {
      if (isAuthenticated) {
        listener.call();
      }
    });
  }

  String? get refreshToken => App.box.get('passport/x-refresh-token');
  void setRefreshToken(String token) {
    App.box.put('passport/x-refresh-token', token);
  }

  String? get accessToken => App.box.get('passport/x-access-token');
  void setAccessToken(String token) {
    App.box.put('passport/x-access-token', token);
  }

  /// A shortcut to obtain the identity in strong type.
  /// Example: `App.credential<User>()`
  T call<T extends Identity>() => identity as T;

  void onFailedAuthorizationFromServer() => signOut();
  Future signOutFromServer();
  Future refreshTokenFromServer();
}

abstract class Identity {}

@immutable
class PrincipalIdentity implements Identity {
  final String id;
  final String username;
  final String name;
  final String? email;
  final String? phone;

  const PrincipalIdentity({
    required this.id,
    required this.username,
    required this.name,
    this.email,
    this.phone,
  });

  factory PrincipalIdentity.fromJson(Map<String, Object?> json) =>
      PrincipalIdentity(
          id: json['id'] as String,
          username: json['username'] as String,
          name: json['name'] as String,
          email: json['email'] as String?);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other.runtimeType == runtimeType &&
            other is PrincipalIdentity &&
            (identical(other.id, id) || other.id == id) &&
            (identical(other.username, username) ||
                other.username == username) &&
            (identical(other.name, name) || other.name == name) &&
            (identical(other.email, email) || other.email == email) &&
            (identical(other.phone, phone) || other.phone == phone));
  }

  @override
  int get hashCode =>
      Object.hash(runtimeType, id, username, name, email, phone);
}

class DefaultPassport extends Passport {
  @override
  Future signOutFromServer() {
    return '/api/auth/signout'.api().post(
      extra: {
        'SIGN_OUT': true,
      },
    );
  }

  @override
  Future refreshTokenFromServer() async {
    return '/api/auth/refresh'.api(
      body: {
        'refreshToken': App.passport.refreshToken,
        'checkSum': Crypto.checkSum(App.passport.refreshToken!)
      },
    ).post(
      extra: {
        'RENEW_CREDENTIAL': true,
      },
    );
  }
}
